summaryrefslogtreecommitdiffstats
path: root/src/katemdi.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/katemdi.h')
-rw-r--r--src/katemdi.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/katemdi.h b/src/katemdi.h
index 58f569a..e886acd 100644
--- a/src/katemdi.h
+++ b/src/katemdi.h
@@ -39,7 +39,7 @@ class Splitter : public TQSplitter
TQ_OBJECT
public:
- Splitter(Qt::Orientation o, TQWidget* tqparent=0, const char* name=0);
+ Splitter(Qt::Orientation o, TQWidget* parent=0, const char* name=0);
~Splitter();
/** Since there is supposed to be only 2 childs of a katesplitter,
@@ -60,7 +60,7 @@ class ToggleToolViewAction : public KToggleAction
public:
ToggleToolViewAction ( const TQString& text, const KShortcut& cut,
- class ToolView *tv, TQObject* tqparent = 0, const char* name = 0 );
+ class ToolView *tv, TQObject* parent = 0, const char* name = 0 );
virtual ~ToggleToolViewAction();
@@ -109,9 +109,9 @@ class ToolView : public TQVBox
* be automatically set to be the focus proxy of the toolview
* @param mainwin main window for this toolview
* @param sidebar sidebar of this toolview
* @param tqparent tqparent widget, e.g. the splitter of one of the sidebars
*/
- ToolView (class MainWindow *mainwin, class Sidebar *sidebar, TQWidget *tqparent);
+ ToolView (class MainWindow *mainwin, class Sidebar *sidebar, TQWidget *parent);
public:
/**
@@ -172,7 +172,7 @@ class Sidebar : public KMultiTabBar
TQ_OBJECT
public:
- Sidebar (KMultiTabBar::KMultiTabBarPosition pos, class MainWindow *mainwin, TQWidget *tqparent);
+ Sidebar (KMultiTabBar::KMultiTabBarPosition pos, class MainWindow *mainwin, TQWidget *parent);
virtual ~Sidebar ();
void setSplitter (Splitter *sp);
@@ -269,7 +269,7 @@ class MainWindow : public KParts::MainWindow
public:
/**
* central widget ;)
* use this as tqparent for your content
* this widget will get focus if a toolview is hidden
* @return central widget
*/
@@ -109,9 +109,9 @@ class ToolView : public TQVBox
* @param mainwin main window for this toolview
* @param sidebar sidebar of this toolview
- * @param tqparent tqparent widget, e.g. the splitter of one of the sidebars
+ * @param parent parent widget, e.g. the splitter of one of the sidebars
*/
@@ -269,7 +269,7 @@ class MainWindow : public KParts::MainWindow
/**
* central widget ;)
- * use this as tqparent for your content
+ * use this as parent for your content
* this widget will get focus if a toolview is hidden
* @return central widget